/*----------------------------------------------------------------------
 *
 * 3DM-GX2 Interface Software
 *
 * (c) 2008 Microstrain, Inc.
 * All rights reserved.
 *
 * www.microstrain.com
 * 310 Hurricane Lane, Suite 4
 * Williston, VT 05495 USA
 * Tel: 802-862-6629
 * Fax: 802-863-4093
 *--------------------------------------------------------------------*/

/*----------------------------------------------------------------------
 * i3dmgx2_CM_CMD.c
 *
 * 3DM-GX2 Sensor device functions.
 *
 * This platform independent module relies on the communication functions 
 * found in either i3dmgx2SerialWin.c or i3dmgx2SerialLinux.c 
 * (your choice, depending on platform).
 *--------------------------------------------------------------------*/
 
#ifndef DEBUG
#define DEBUG 0
#endif

#include <stdio.h>
#include "i3dmgx2_Cont.h"
#include "i3dmgx2Utils.h"
#include "i3dmgx2Errors.h"
#include "i3dmgx2Serial.h"

HANDLE portHandles[MAX_PORT_NUM];
char *axis[] = { "X", "Y", "Z"};

/*----------------------------------------------------------------------
 * i3dmgx2_openPort
 *
 * Open a serial communications port. (platform independent).
 *
 * parameters   portNum  : a port number (1..n).
 *--------------------------------------------------------------------*/

int i3dmgx2_openPort(int portNum, int baudrate, int size, int parity, 
					 int stopbits, int inputBuff, int outputBuff) {
    int errcheck;
    int porth;

    errcheck = openPort(portNum, inputBuff, outputBuff);
    if (errcheck<0) {
        return errcheck;
    }
    porth = errcheck;  /* no error, so this is the port number. */

    /* set communications parameters */
    errcheck = setCommParameters(porth, baudrate, size, parity, stopbits);
    if (errcheck!=I3DMGX2_COMM_OK) {
        return errcheck;
    }

    /* set timeouts */
    errcheck = setCommTimeouts(porth, 50, 50); /* Read Write */
    if (errcheck!=I3DMGX2_COMM_OK) {
        return errcheck;
    }
    return porth;
}

/*----------------------------------------------------------------------
 * i3dmgx2_closeDevice
 *
 * parameters   portNum      : the number of the sensor device 
 *                                
 * Close a device, and also any underlying port.
 *--------------------------------------------------------------------*/
void i3dmgx2_closeDevice(int portNum) {
    
       closePort(portNum);    
}
/*----------------------------------------------------------------------
 * Get_Volts(portNum, chOption, &RBuff[0]);
 *
 * parameters   portNum : the number of the sensor device (1..n)
 *              pI3Record : struct to receive floating point values for
 *							Accel (x,y,z) and Ang (x,y,z)
 *
 * returns:     errorCode : I3DMGX2_OK if succeeded, otherwise returns
 *                          an error code.
 *--------------------------------------------------------------------*/
int Get_Volts(int portNum, char C_ID, BYTE* Bresponse) {
    int responseLength = 3;
	int status;
	//BYTE Bresponse[3];
	
    		
	status = sendBuffData(portNum, &C_ID, 1);
    //if (DEBUG) printf("send_data: tx status : %d\n", status);
	if (status == I3DMGX2_COMM_OK) {
    	status = receiveData(portNum, &Bresponse[0], responseLength);
	    //printf("Status is %d, response = %02x, bytes returned %d\n", status, Bresponse[0], responseLength);
	}
	return status;
}


/*-------------- end of i3dmgx2Adapter.c ----------------------*/
