/*----------------------------------------------------------------------
 *
 * I3DM-GX2 Interface Software
 *
 * (c) 2008 Microstrain, Inc.
 * All rights reserved.
 *
 * www.microstrain.com
 * 310 Hurricane Lane, Suite 4
 * Williston, VT 05495 USA
 * Tel: 802-862-6629
 * Fax: 802-863-4093
 *--------------------------------------------------------------------*/

/*----------------------------------------------------------------------
 * i3dmgx2_Main_CM.c
 *
 * Main for the 3DM-GX2 Adapter continious/poll data console application.
 *--------------------------------------------------------------------*/		
#include <stdio.h>
#include <sys/timeb.h>
#include <time.h>
#include "i3dmgx2Errors.h"
#include "i3dmgx2_Cont.h"
#include "i3dmgx2Utils.h"
#include "i3dmgx2Utils_CM.h"

int GetComPort(); //prompt user for comport and opens it
void PollData(int portNum); 
void Channel_connect(int portNum, char C_ID, int chOption);


int main(int argc, char* argv[])
{
	BOOL bQuit = FALSE;
	BOOL bPrintHeader = TRUE;
    int portNum = 0;
	int Ccount = 0;
	I3dmgx2Set pRecord;
	BYTE Ch_Choice;
	while (portNum <=0){
        portNum = GetComPort();
		if (Ccount++ > 4)
			exit(1);
	}
   
	while(!bQuit){
		int chOption = 0;

		if(bPrintHeader)
		{
			printf("\n");
			printf("Enter A Channel number to connect to:\n");
			printf("      valid values are between 0 and 7\n");
			printf("      or enter 8 To Quit the application\n");

			bPrintHeader = FALSE;
		}

		//read option from the keyboard
		while(!ReadCharNoReturn(&chOption))
		{
			Sleep(50);
		}
		
        if(chOption > 55)
			  bQuit = TRUE;
		else{
			switch (chOption){
				case 48: chOption = 0;
					     printf("Channel Number %d Selected\n",chOption);
						 Channel_connect(portNum, 'f', chOption);
			             bPrintHeader = TRUE; 
						 break;
				case 49: chOption = 1;
					     printf("Channel Number %d Selected\n",chOption);
						 Channel_connect(portNum, 'x', chOption);
			             bPrintHeader = TRUE; 
						 break;
				case 50: chOption = 2;
					     printf("Channel Number %d Selected\n",chOption);
						 Channel_connect(portNum, 'y', chOption);
			             bPrintHeader = TRUE; 
						 break;
				case 51: chOption = 3;
					     printf("Channel Number %d Selected\n",chOption);
						 Channel_connect(portNum, 'w', chOption);
			             bPrintHeader = TRUE; 
						 break;
				case 52: chOption = 4;
					     printf("Channel Number %d Selected\n",chOption);
						 Channel_connect(portNum, 'm', chOption);
			             bPrintHeader = TRUE; 
						 break;
				case 53: chOption = 5;
					     printf("Channel Number %d Selected\n",chOption);
						 Channel_connect(portNum, 'n', chOption);
			             bPrintHeader = TRUE; 
						 break;
				case 54: chOption = 6;
					     printf("Channel Number %d Selected\n",chOption);
						 Channel_connect(portNum, 'o', chOption);
			             bPrintHeader = TRUE; 
						 break;
				case 55: chOption = 7;
					     printf("Channel Number %d Selected\n",chOption);
						 Channel_connect(portNum, 'p', chOption);
			             bPrintHeader = TRUE; 
						 break;
				case 56: chOption = 0;
					     printf("Channel Number %d\n",chOption);
						 bQuit = TRUE; 
						 break;
				default: printf("Invalid option");
					     bPrintHeader = TRUE;
						 break;
			}
			
		}
		
	}
				
	return 0;
}

//===========================================================================
// GetComPort
//---------------------------------------------------------------------------
// Description: Prompt user for the comport and then opens it.  The user is 
//              prompted until a valid comport is selected and successfully 
//              opened.
//
// Return: HANDLE - handle to the opened comport
//===========================================================================
int GetComPort()
{
	int portNum   = 0;
	int iComPort  = 0;
	int errCount = 0;
	int MaxFail = 5;
	//Get comport number ask user for the comport number and open it
	while(portNum == 0)
	{
		printf("Enter Comport to use:");
		scanf("%d", &iComPort);
		
		/* open a port, map a device */
        portNum = i3dmgx2_openPort(iComPort, 9600, 8, 0, 1, 1024, 1024); //115200, 8, 0, 1, 1024, 1024);
        if (portNum<0) {
            printf("port open failed. ");
            printf("Comm error %d, %s:\n", portNum, explainError(portNum));
			if (errCount++ >= MaxFail)
				exit(-1);
			iComPort = 0;
		}
		else {
             printf("\n   Using Comm Port #%d \n", portNum);

		}
		
	} 

	return portNum;
}

//===========================================================================
// Channel_connect(portNum, chOption)
//---------------------------------------------------------------------------
// Description: Connects to a user specified channel on the smart motherboard
//
// Return: voltage
//===========================================================================
void Channel_connect(int portNum, char C_ID, int chOption)
{
	int status = 0, i = 0;
	BYTE RBuff[3];
	BYTE code_SM;
	BYTE SM_MSB;
	BYTE SM_LSB;
	float SM_Volts;

	status = Get_Volts(portNum, C_ID, &RBuff[0]);
	if(status == 0)
	{
		if(RBuff[0] > 1){
		   SM_Volts = (((RBuff[1]*256+RBuff[2])-8192)*0.0006103);
		   printf("\n");
		   printf("Channel #:%d\n", chOption);
		   printf("Volts %f\n", SM_Volts);
		   }
		else
			printf("Channel not available\n");
	}
	else
	{
		printf("Get Volts() on Channel %d Failed\n", chOption);
		printf("Error Code: %d\n", status); 
	}
}
